@@ -315,8 +315,9 @@ def inject_signal(array,t0,f_obs,f_sampling,A,phase):
     block_global_id     = cuda.blockIdx.x*cuda.blockIdx.y+cuda.blockIdx.x
     nb_thread_per_block = cuda.blockDim.x*cuda.blockDim.y
     thread_local_id     = cuda.threadIdx.x*cuda.threadIdx.y+cuda.threadIdx.x
-    thread_global_id    = block_global_id*nb_thread_per_block + thread_local_id
+    #thread_global_id    = block_global_id*nb_thread_per_block + thread_local_id
 
+    thread_global_id    = cuda.grid(1)
     #read the frequency at the specific time
     f = f_obs[thread_global_id]
 
